=========
Changelog
=========

GitHub holds releases, too
==========================

More information can be found on GitHub in the `releases section
<https://github.com/Kwpolska/merge_args/releases>`_.

Version History
===============

0.1.0
    Initial release.
